@@ -86,6 +86,7 @@ _eXosip_transaction_init (osip_transaction_t ** transaction,
 		return i;
 	}
 #ifdef SRV_RECORD
+	memset(&record, 0, sizeof(osip_srv_record_t));
 	i = _eXosip_srv_lookup(*transaction, message, &record);
 	if (i<0)
 	{
@@ -1006,7 +1007,7 @@ eXosip_find_authentication_info (const char *username, const char *realm)
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_INFO3, NULL,
                    "INFO: authinfo: %s %s\n", realm, authinfo->realm));
-      if (authinfo->realm == NULL || authinfo->realm[0] == '\0')
+      if ((authinfo->realm == NULL || authinfo->realm[0] == '\0') && fallback==NULL)
         {
           fallback = authinfo;
       } else if (strcmp (realm, authinfo->realm) == 0
